@@ -4,7 +4,7 @@ function(matr){
 # Giraudoux 08.2003
 # renvoie les valeurs du Xi2 d'un tableau de contingence
     
-    expect<-valat(matr)
+    expect<-chisq.test(matr)$expected
     tabchisq<-expect
     
     for (i in 1:length(matr[,1])){ # de la premiere  la derniere ligne
